package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.BusinessBulletin;
import com.ruoyi.mall.domain.Vo.BusinessBulletinResponse;
import com.ruoyi.mall.domain.Vo.BusinessBulletinVo;

/**
 * 公告Service接口
 * 
 * @author ruoyi
 * @date 2023-10-25
 */
public interface IBusinessBulletinService 
{
    /**
     * 查询公告
     * 
     * @param bulletinId 公告主键
     * @return 公告
     */
    public BusinessBulletin selectBusinessBulletinByBulletinId(Long bulletinId);

    /**
     * 查询公告列表
     * 
     * @param businessBulletin 公告
     * @return 公告集合
     */
    public List<BusinessBulletin> selectBusinessBulletinList(BusinessBulletin businessBulletin);

    /**一周内 热度*/
    List<BusinessBulletinResponse> getHotList(BusinessBulletin businessBulletin);
    /**
     * 新增公告
     * 
     * @param businessBulletin 公告
     * @return 结果
     */
    public int insertBusinessBulletin(BusinessBulletin businessBulletin);

    /**
     * 修改公告
     * 
     * @param businessBulletin 公告
     * @return 结果
     */
    public int updateBusinessBulletin(BusinessBulletin businessBulletin);

    /**
     * 批量删除公告
     * 
     * @param bulletinIds 需要删除的公告主键集合
     * @return 结果
     */
    public int deleteBusinessBulletinByBulletinIds(Long[] bulletinIds);

    /**
     * 删除公告信息
     * 
     * @param bulletinId 公告主键
     * @return 结果
     */
    public int deleteBusinessBulletinByBulletinId(Long bulletinId);
}
