package com.ruoyi.mall.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.BusinessBulletin;
import com.ruoyi.mall.service.IBusinessBulletinService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 公告Controller
 * 
 * @author ruoyi
 * @date 2023-10-25
 */
@RestController
@RequestMapping("/mall/bulletin")
public class BusinessBulletinController extends BaseController
{
    @Autowired
    private IBusinessBulletinService businessBulletinService;

    /**
     * 查询公告列表
     */
    @PreAuthorize("@ss.hasPermi('mall:bulletin:list')")
    @GetMapping("/list")
    public TableDataInfo list(BusinessBulletin businessBulletin)
    {
        startPage();
        List<BusinessBulletin> list = businessBulletinService.selectBusinessBulletinList(businessBulletin);
        return getDataTable(list);
    }

    /**
     * 导出公告列表
     */
    @PreAuthorize("@ss.hasPermi('mall:bulletin:export')")
    @Log(title = "公告", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusinessBulletin businessBulletin)
    {
        List<BusinessBulletin> list = businessBulletinService.selectBusinessBulletinList(businessBulletin);
        ExcelUtil<BusinessBulletin> util = new ExcelUtil<BusinessBulletin>(BusinessBulletin.class);
        util.exportExcel(response, list, "公告数据");
    }

    /**
     * 获取公告详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:bulletin:query')")
    @GetMapping(value = "/{bulletinId}")
    public AjaxResult getInfo(@PathVariable("bulletinId") Long bulletinId)
    {
        return AjaxResult.success(businessBulletinService.selectBusinessBulletinByBulletinId(bulletinId));
    }

    /**
     * 新增公告
     */
    @PreAuthorize("@ss.hasPermi('mall:bulletin:add')")
    @Log(title = "公告", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusinessBulletin businessBulletin)
    {
        return toAjax(businessBulletinService.insertBusinessBulletin(businessBulletin));
    }

    /**
     * 修改公告
     */
    @PreAuthorize("@ss.hasPermi('mall:bulletin:edit')")
    @Log(title = "公告", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusinessBulletin businessBulletin)
    {
        return toAjax(businessBulletinService.updateBusinessBulletin(businessBulletin));
    }

    /**
     * 删除公告
     */
    @PreAuthorize("@ss.hasPermi('mall:bulletin:remove')")
    @Log(title = "公告", businessType = BusinessType.DELETE)
	@DeleteMapping("/{bulletinIds}")
    public AjaxResult remove(@PathVariable Long[] bulletinIds)
    {
        return toAjax(businessBulletinService.deleteBusinessBulletinByBulletinIds(bulletinIds));
    }
}
